# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
💚 Fix docs | [6](https://github.com/laminlabs/bionty/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 |
⬆️ Update lb | [5](https://github.com/laminlabs/bionty/pull/5) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 | 0.40.2
👷 Upload docs | [4](https://github.com/laminlabs/bionty/pull/4) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 | 0.40.1
💚 Fix docs | [3](https://github.com/laminlabs/bionty/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
📝 Updated readme | [2](https://github.com/laminlabs/bionty/pull/2) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
🎨 Import orms from lb | [1](https://github.com/laminlabs/bionty/pull/1) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
